==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/igc-geographic-symbol-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { ScatterItemSearchMode_$type } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMarkerSeriesComponent } from "./igc-geographic-marker-series-component";
import { GeographicSymbolSeries } from "./GeographicSymbolSeries";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export let IgcGeographicSymbolSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicSymbolSeriesComponent extends IgcGeographicMarkerSeriesComponent {
        createImplementation() {
            return new GeographicSymbolSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._assigningScatterStyle = null;
            this._assigningScatterStyle_wrapped = null;
            this._assigningScatterMarkerStyle = null;
            this._assigningScatterMarkerStyle_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicSymbolSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = names;
            }
            return IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent;
        }
        static register() {
            if (!IgcGeographicSymbolSeriesComponent._isElementRegistered) {
                IgcGeographicSymbolSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicSymbolSeriesComponent.htmlTagName, IgcGeographicSymbolSeriesComponent);
            }
        }
        /**
         * Gets whether the series has only marker as visuals
        */
        get hasOnlyMarkers() {
            return this.i.dy;
        }
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get latitudeMemberPath() {
            return this.i.vr;
        }
        set latitudeMemberPath(v) {
            this.i.vr = v;
        }
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get longitudeMemberPath() {
            return this.i.vt;
        }
        set longitudeMemberPath(v) {
            this.i.vt = v;
        }
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get markerCollisionAvoidance() {
            return this.i.vd;
        }
        set markerCollisionAvoidance(v) {
            this.i.vd = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.vd));
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
        */
        get isCustomScatterStyleAllowed() {
            return this.i.vk;
        }
        set isCustomScatterStyleAllowed(v) {
            this.i.vk = ensureBool(v);
            this._a("isCustomScatterStyleAllowed", this.i.vk);
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
        */
        get isCustomScatterMarkerStyleAllowed() {
            return this.i.vj;
        }
        set isCustomScatterMarkerStyleAllowed(v) {
            this.i.vj = ensureBool(v);
            this._a("isCustomScatterMarkerStyleAllowed", this.i.vj);
        }
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get itemSearchMode() {
            return this.i.ve;
        }
        set itemSearchMode(v) {
            this.i.ve = ensureEnum(ScatterItemSearchMode_$type, v);
            this._a("itemSearchMode", enumToString(ScatterItemSearchMode_$type, this.i.ve));
        }
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get itemSearchThreshold() {
            return this.i.vm;
        }
        set itemSearchThreshold(v) {
            this.i.vm = +v;
            this._a("itemSearchThreshold", this.i.vm);
        }
        /**
         * Event raised when Assigning Category Style
        */
        get assigningScatterStyle() {
            return this._assigningScatterStyle;
        }
        set assigningScatterStyle(ev) {
            if (this._assigningScatterStyle_wrapped !== null) {
                this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
                this._assigningScatterStyle_wrapped = null;
                this._assigningScatterStyle = null;
            }
            this._assigningScatterStyle = ev;
            this._assigningScatterStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterStyle) {
                    this.beforeAssigningScatterStyle(this, outerArgs);
                }
                if (this._assigningScatterStyle) {
                    this._assigningScatterStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            ;
        }
        /**
         * Event raised when Assigning Scatter Marker Style
        */
        get assigningScatterMarkerStyle() {
            return this._assigningScatterMarkerStyle;
        }
        set assigningScatterMarkerStyle(ev) {
            if (this._assigningScatterMarkerStyle_wrapped !== null) {
                this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
                this._assigningScatterMarkerStyle_wrapped = null;
                this._assigningScatterMarkerStyle = null;
            }
            this._assigningScatterMarkerStyle = ev;
            this._assigningScatterMarkerStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterMarkerStyle) {
                    this.beforeAssigningScatterMarkerStyle(this, outerArgs);
                }
                if (this._assigningScatterMarkerStyle) {
                    this._assigningScatterMarkerStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            ;
        }
    }
    IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = null;
    IgcGeographicSymbolSeriesComponent.htmlTagName = "igc-geographic-symbol-series";
    IgcGeographicSymbolSeriesComponent._isElementRegistered = false;
    return IgcGeographicSymbolSeriesComponent;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/igc-geographic-symbol-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { ScatterItemSearchMode_$type } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMarkerSeriesComponent } from "./igc-geographic-marker-series-component";
import { GeographicSymbolSeries } from "./GeographicSymbolSeries";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export let IgcGeographicSymbolSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicSymbolSeriesComponent extends IgcGeographicMarkerSeriesComponent {
        createImplementation() {
            return new GeographicSymbolSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._assigningScatterStyle = null;
            this._assigningScatterStyle_wrapped = null;
            this._assigningScatterMarkerStyle = null;
            this._assigningScatterMarkerStyle_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicSymbolSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = names;
            }
            return IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent;
        }
        static register() {
            if (!IgcGeographicSymbolSeriesComponent._isElementRegistered) {
                IgcGeographicSymbolSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicSymbolSeriesComponent.htmlTagName, IgcGeographicSymbolSeriesComponent);
            }
        }
        /**
         * Gets whether the series has only marker as visuals
        */
        get hasOnlyMarkers() {
            return this.i.ej;
        }
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get latitudeMemberPath() {
            return this.i.yo;
        }
        set latitudeMemberPath(v) {
            this.i.yo = v;
        }
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get longitudeMemberPath() {
            return this.i.yq;
        }
        set longitudeMemberPath(v) {
            this.i.yq = v;
        }
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get markerCollisionAvoidance() {
            return this.i.ya;
        }
        set markerCollisionAvoidance(v) {
            this.i.ya = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.ya));
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
        */
        get isCustomScatterStyleAllowed() {
            return this.i.yh;
        }
        set isCustomScatterStyleAllowed(v) {
            this.i.yh = ensureBool(v);
            this._a("isCustomScatterStyleAllowed", this.i.yh);
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
        */
        get isCustomScatterMarkerStyleAllowed() {
            return this.i.yg;
        }
        set isCustomScatterMarkerStyleAllowed(v) {
            this.i.yg = ensureBool(v);
            this._a("isCustomScatterMarkerStyleAllowed", this.i.yg);
        }
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get itemSearchMode() {
            return this.i.yb;
        }
        set itemSearchMode(v) {
            this.i.yb = ensureEnum(ScatterItemSearchMode_$type, v);
            this._a("itemSearchMode", enumToString(ScatterItemSearchMode_$type, this.i.yb));
        }
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get itemSearchThreshold() {
            return this.i.yj;
        }
        set itemSearchThreshold(v) {
            this.i.yj = +v;
            this._a("itemSearchThreshold", this.i.yj);
        }
        /**
         * Event raised when Assigning Category Style
        */
        get assigningScatterStyle() {
            return this._assigningScatterStyle;
        }
        set assigningScatterStyle(ev) {
            if (this._assigningScatterStyle_wrapped !== null) {
                this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
                this._assigningScatterStyle_wrapped = null;
                this._assigningScatterStyle = null;
            }
            this._assigningScatterStyle = ev;
            this._assigningScatterStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterStyle) {
                    this.beforeAssigningScatterStyle(this, outerArgs);
                }
                if (this._assigningScatterStyle) {
                    this._assigningScatterStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            ;
        }
        /**
         * Event raised when Assigning Scatter Marker Style
        */
        get assigningScatterMarkerStyle() {
            return this._assigningScatterMarkerStyle;
        }
        set assigningScatterMarkerStyle(ev) {
            if (this._assigningScatterMarkerStyle_wrapped !== null) {
                this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
                this._assigningScatterMarkerStyle_wrapped = null;
                this._assigningScatterMarkerStyle = null;
            }
            this._assigningScatterMarkerStyle = ev;
            this._assigningScatterMarkerStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterMarkerStyle) {
                    this.beforeAssigningScatterMarkerStyle(this, outerArgs);
                }
                if (this._assigningScatterMarkerStyle) {
                    this._assigningScatterMarkerStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            ;
        }
    }
    IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = null;
    IgcGeographicSymbolSeriesComponent.htmlTagName = "igc-geographic-symbol-series";
    IgcGeographicSymbolSeriesComponent._isElementRegistered = false;
    return IgcGeographicSymbolSeriesComponent;
})();
